**EN 1993-1-9 - May 2005
Eurocode 3: Design of steel structures
Part 1-9: Fatigue**

The table presents a list of tables from the Eurocode 3 standards for steel structures, tracking their implementation status (:x: or :heavy_check_mark:)
and any pertinent remarks. The 'Object Name' column references the corresponding Python entities inside of Blueprints.

Total of 16 tables present.

| Table number | Done | Remarks | Object name |
|:-------------|:----:|:--------|:------------|
| 3.1          | :x:  |         |             |
| 4.1          | :x:  |         |             |
| 4.2          | :x:  |         |             |
| 8.1          | :x:  |         |             |
| 8.2          | :x:  |         |             |
| 8.3          | :x:  |         |             |
| 8.4          | :x:  |         |             |
| 8.5          | :x:  |         |             |
| 8.6          | :x:  |         |             |
| 8.7          | :x:  |         |             |
| 8.8          | :x:  |         |             |
| 8.9          | :x:  |         |             |
| 8.10         | :x:  |         |             |
| B.1          | :x:  |         |             |
| NB.1         | :x:  |         |             |
| NB.2         | :x:  |         |             |
